@@ -714,6 +714,7 @@ class RobotValidator:
         '^yolinkBot',
         'bixo',
         'crawler',
+        'ELB-HealthChecker',
         'Exabot',
         'Google Web Preview',
         'Googlebot',
@@ -725,8 +726,10 @@ class RobotValidator:
         'MS Search',
         'MSIECrawler',
         'naver.com',
+        'NewRelicPinger',
         'Nutch',
         'openwebspider.org',
+        'org_bot',
         'PycURL',
         'Python',
         'ReverseGet',
@@ -736,11 +739,13 @@ class RobotValidator:
         'SeznamBot',
         'SISTRIX crawler',
         'SiteIntel.net Bot',
+        'Slackbot-LinkExpanding',
         'Speedy Spider',
         'Spider',
         'StumbleUpon;',
         'TLSProber',
         'trendictionbot',
+        'TwilioProxy',
         'urllib',
         'verticalpigeon.com',
         'VoilaBot',
